@@ -28,9 +28,8 @@ import shutil
 from .config import LazygalConfig
 from .config import USER_CONFIG_PATH, LazygalConfigDeprecated
 from .sourcetree import SOURCEDIR_CONFIGFILE
-from .pygexiv2 import GExiv2
+from .metadata import GExiv2
 
-from . import py2compat
 from . import make
 from . import pathutils
 from . import sourcetree
@@ -64,7 +63,7 @@ class SubgalSort(make.MakeTask):
     """
 
     def __init__(self, webgal_dir):
-        make.MakeTask.__init__(self)
+        super().__init__()
         self.set_dep_only()
         self.webgal_dir = webgal_dir
 
@@ -116,7 +115,7 @@ class SubgalBreak(make.MakeTask):
     """
 
     def __init__(self, webgal_dir):
-        make.MakeTask.__init__(self)
+        super().__init__()
         self.webgal_dir = webgal_dir
 
         self.__last_page_number = -1
@@ -196,7 +195,7 @@ class SubgalBreak(make.MakeTask):
 class WebalbumMediaTask(make.GroupTask):
 
     def __init__(self, webgal, media):
-        super(WebalbumMediaTask, self).__init__()
+        super().__init__()
 
         self.webgal = webgal
         self.media = media
@@ -210,16 +209,17 @@ class WebalbumMediaTask(make.GroupTask):
 
         for size_name in self.webgal.browse_sizes:
             self.resized[size_name] = self.get_resized(size_name)
-            self.add_dependency(self.resized[size_name])
-
-            if self.webgal.original and not self.webgal.orig_base:
-                self.add_dependency(self.get_original())
+            if self.resized[size_name] not in self.deps:
+                self.add_dependency(self.resized[size_name])
 
             if self.webgal.album.theme.kind == 'static':
                 self.browse_pages[size_name] = self.get_browse_page(size_name)
                 if self.webgal.album.force_gen_pages:
                     self.browse_pages[size_name].stamp_delete()
 
+        if self.webgal.original and not self.webgal.orig_base:
+            self.add_dependency(self.get_original())
+
     def set_next(self, media):
         self.next = media
         if media:
@@ -247,7 +247,7 @@ class WebalbumMediaTask(make.GroupTask):
         return genpage.WebalbumBrowsePage(self.webgal, size_name, self)
 
     def make(self):
-        super(WebalbumMediaTask, self).make()
+        super().make()
         self.webgal.media_done()
 
 
@@ -257,7 +257,7 @@ class WebalbumImageTask(WebalbumMediaTask):
     """
 
     def __init__(self, webgal, image):
-        super(WebalbumImageTask, self).__init__(webgal, image)
+        super().__init__(webgal, image)
 
         self.thumb = genmedia.ImageOtherSize(self.webgal, self.media,
                                              genmedia.THUMB_SIZE_NAME)
@@ -268,9 +268,7 @@ class WebalbumImageTask(WebalbumMediaTask):
             return self.get_original_or_symlink()
         else:
             sized = genmedia.ImageOtherSize(self.webgal, self.media, size_name)
-            self.media.get_size() # probe size to check if media is broken
-            if not self.media.broken\
-            and sized.get_size() == sized.source_media.get_size():
+            if sized.get_size() == sized.source_media.get_size():
                 # Do not process if size is the same
                 return self.get_original()
             else:
@@ -285,23 +283,17 @@ class WebalbumVideoTask(WebalbumMediaTask):
     def __init__(self, webgal, video):
         self.webvideo = None
 
-        super(WebalbumVideoTask, self).__init__(webgal, video)
+        super().__init__(webgal, video)
 
         self.thumb = genmedia.VideoThumb(self.webgal, self.media,
                                          genmedia.THUMB_SIZE_NAME)
-
-        self.add_dependency(self.webvideo)
+        self.add_dependency(self.thumb)
 
     def get_resized(self, size_name):
         if not self.webvideo:
-            if self.webgal.newsizers[genmedia.VIDEO_SIZE_NAME] == 'original'\
-            and self.media.extension in ('.webm', '.mp4'):
-                # do not transcode webm videos
-                self.webvideo = self.get_original_or_symlink()
-            else:
-                self.webvideo = genmedia.WebVideo(self.webgal, self.media,
-                                                  genmedia.VIDEO_SIZE_NAME,
-                                                  self.webgal.progress)
+            self.webvideo = genmedia.WebVideo(self.webgal, self.media,
+                                              genmedia.VIDEO_SIZE_NAME,
+                                              self.webgal.progress)
 
         return self.webvideo
 
@@ -316,14 +308,11 @@ class WebalbumDir(make.GroupTask):
         self.path = os.path.join(album_dest_dir, self.source_dir.strip_root())
         if self.path.endswith(os.sep): self.path = os.path.dirname(self.path)
 
-        super(WebalbumDir, self).__init__()
+        super().__init__()
 
         self.progress = progress
 
-        self.add_dependency(self.source_dir)
         self.subgals = subgals
-        for srcdir in self.source_dir.subdirs:
-            self.add_dependency(srcdir)
         self.album = album
         self.feed = None
 
@@ -335,9 +324,11 @@ class WebalbumDir(make.GroupTask):
 
         self.pindex = pindex.PersistentIndex(self)
         self.add_dependency(self.pindex)
+        self.webassets = pindex.WebAssets(self)
+        self.webassets.add_dependency(self.pindex)
 
     def populate_deps(self):
-        super(WebalbumDir, self).populate_deps()
+        super().populate_deps()
 
         for s in self.subgals:
             if not s.has_media_below():
@@ -347,7 +338,8 @@ class WebalbumDir(make.GroupTask):
         self.sort_task = SubgalSort(self)
         self.sort_task.add_dependency(self.source_dir)
         for media in self.source_dir.medias:
-            if self.tagfilters and media.info() is not None:
+            media.load_metadata(self.pindex)
+            if self.tagfilters:
                 # tag-filtering is requested
                 res = True
                 for tagf in self.tagfilters:
@@ -359,11 +351,12 @@ class WebalbumDir(make.GroupTask):
                     # we look for tag words, partial matches are not wanted
                     regex = re.compile(r"\b" + tagf + r"\b")
 
-                    kwlist = ' '.join(media.info().get_keywords())
+                    kwlist = ' '.join(media.md['metadata']['keywords'])
                     if re.search(regex, kwlist) is None:
                         res = False
                         break
-                if res is False:
+                if not res:
+                    self.pindex.unpublish_media(media)
                     self.media_done()
                     continue
 
@@ -386,22 +379,11 @@ class WebalbumDir(make.GroupTask):
                 self.medias.append(media_task)
                 self.add_dependency(media_task)
 
-        # Create the directory if it does not exist
-        if not os.path.isdir(self.path) and self.has_media_below():
-            logging.info(_("  MKDIR %%WEBALBUMROOT%%/%s"),
-                         self.source_dir.strip_root())
-            logging.debug("(%s)", self.path)
-            os.makedirs(self.path)
-
-        if self.pindex.dirzip():
-            self.dirzip = genfile.WebalbumArchive(self)
-            self.add_dependency(self.dirzip)
-            self.pindex.add_dependency(self.dirzip)
-
         self.index_pages = []
 
         if self.has_media_below() and not self.should_be_flattened():
             self.break_task = SubgalBreak(self)
+            self.break_task.add_dependency(self.pindex)
 
             if self.thumbs_per_page > 0:
                 self.break_task.add_dependency(self.sort_task)
@@ -415,6 +397,12 @@ class WebalbumDir(make.GroupTask):
         else:
             self.break_task = None
 
+        self.dirzip = None
+        if self.config.get('webgal', 'dirzip') and len(self.medias) > 1:
+            self.dirzip = genfile.WebalbumArchive(self)
+            self.add_dependency(self.dirzip)
+            self.webassets.add_dependency(self.dirzip)
+
     def __parse_browse_sizes(self, sizes_defs):
         fixed_sizes_defs = sizes_defs
         if isinstance(sizes_defs, dict):
@@ -430,7 +418,7 @@ class WebalbumDir(make.GroupTask):
                 first = False
 
         for size_defs in fixed_sizes_defs:
-            name = py2compat.u(size_defs['name'], locale.getpreferredencoding())
+            name = size_defs['name']
             if name == genmedia.THUMB_SIZE_NAME:
                 raise ValueError(_("Size name '%s' is reserved for internal processing.") % genmedia.THUMB_SIZE_NAME)
             self.__parse_size(name, size_defs['defs'])
@@ -447,7 +435,7 @@ class WebalbumDir(make.GroupTask):
             try:
                 self.newsizers[size_name] = newsize.get_newsizer(size_string)
             except newsize.NewsizeStringParseError:
-                raise ValueError(_("'%s' for size '%s' does not describe a known size syntax.") % (py2compat.u(size_string, locale.getpreferredencoding()), size_name, ))
+                raise ValueError(_("'%s' for size '%s' does not describe a known size syntax.") % (size_string, size_name, ))
 
     def __load_tpl_vars(self):
         # Load tpl vars from config
@@ -456,7 +444,6 @@ class WebalbumDir(make.GroupTask):
             tpl_vars = {}
             for option in self.config.options('template-vars'):
                 value = self.config.get('template-vars', option)
-                value = py2compat.u(value, locale.getpreferredencoding())
                 tpl_vars[option] = genshi.core.Markup(value)
 
         return tpl_vars
@@ -559,7 +546,7 @@ class WebalbumDir(make.GroupTask):
     def register_output(self, output):
         # We only care about output in the current directory
         if os.path.dirname(output) == self.path:
-            super(WebalbumDir, self).register_output(output)
+            super().register_output(output)
 
     def register_feed(self, feed):
         self.feed = feed
@@ -653,8 +640,6 @@ class WebalbumDir(make.GroupTask):
                              dirnames))
         for dest_file in os.listdir(self.path):
             dest_file = os.path.join(self.path, dest_file)
-            # FIXME: No clue why this happens, but it happens!
-            dest_file = py2compat.u(dest_file, sys.getfilesystemencoding())
             if dest_file not in self.output_items and\
                 dest_file not in expected_dirs and\
                     dest_file not in extra_files:
@@ -679,7 +664,7 @@ class WebalbumDir(make.GroupTask):
             self.album.cleanup(dest_file, self.path)
 
     def make(self, force=False):
-        super(WebalbumDir, self).make(force)
+        super().make(force)
         self.update_build_status()
 
     def media_done(self):
@@ -699,7 +684,7 @@ class SharedFiles(make.FileMakeObject):
             logging.debug("(%s)", self.path)
             os.makedirs(self.path)
 
-        super(SharedFiles, self).__init__(self.path)
+        super().__init__(self.path)
 
         self.expected_shared_files = []
         for shared in self.album.theme.shared_files:
@@ -885,8 +870,6 @@ class Album(object):
     def generate(self, dest_dir=None, progress=None):
         if dest_dir is None:
             dest_dir = self.config.get('global', 'output-directory')
-        else:
-            dest_dir = py2compat.u(dest_dir, sys.getfilesystemencoding())
         sane_dest_dir = os.path.abspath(os.path.expanduser(dest_dir))
 
         if not progress:
