@@ -28,14 +28,14 @@ from . import make
 from . import genfile
 from . import eyecandy
 from . import mediautils
-from lazygal.pygexiv2 import GExiv2
+from .metadata import GExiv2
 
 
 THUMB_SIZE_NAME = 'thumb'
 VIDEO_SIZE_NAME = 'video'
 
 
-class ResizedImage(genfile.WebalbumFile):
+class ResizedMedia(genfile.WebalbumFile):
 
     force_extension = None
 
@@ -46,7 +46,7 @@ class ResizedImage(genfile.WebalbumFile):
                                                         size_name,
                                                         self.force_extension)
         path = os.path.join(self.webgal.path, self.filename)
-        genfile.WebalbumFile.__init__(self, path, webgal)
+        super().__init__(path, webgal)
 
         self.newsizer = self.webgal.newsizers[size_name]
         self.size = None
@@ -67,31 +67,20 @@ class ResizedImage(genfile.WebalbumFile):
         logging.info("  %s %s", self.VERB, media_rel_path)
         logging.debug("(%s)", self.path)
 
-        im = self.resize(self.get_image())
-        self.save(im)
+        if not self.source_media.broken:
+            self.do_build()
 
-    def get_image(self):
-        raise NotImplementedError
 
-    def call_build(self):
-        try:
-            self.build()
-        except IOError:
-            logging.error(_("  %s is BROKEN, skipped"),
-                          self.source_media.filename)
-            if not self.source_media.broken:
-                self.source_media.broken = True
+class ImageOtherSize(ResizedMedia):
 
-            # Make the system believe the file was built a long time ago.
-            self.stamp_build(0)
-        else:
-            self.stamp_build()
+    def __init__(self, webgal, source_image, size_name):
+        super().__init__(webgal, source_image, size_name)
+        self.rotation = None
+
+    def get_verb(self): return _('RESIZE')
+    VERB = property(get_verb)
 
     def resize(self, im):
-        self.source_media.get_size()  # Probe brokenness
-        if self.source_media.broken:
-            raise IOError('Failed to get media size')
-
         new_size = self.get_size()
 
         im.draft(None, new_size)
@@ -112,21 +101,13 @@ class ResizedImage(genfile.WebalbumFile):
                         raise
             calibrated = True
 
-
-class ImageOtherSize(ResizedImage):
-
-    def __init__(self, webgal, source_image, size_name):
-        super(ImageOtherSize, self).__init__(webgal, source_image, size_name)
-        self.rotation = None
-
-    def get_verb(self): return _('RESIZE')
-    VERB = property(get_verb)
+        if self.webgal.config.get('webgal', 'publish-metadata'):
+            self.copy_metadata()
 
     def get_rotation(self):
         if self.rotation is None:
-            source_media_md = self.source_media.info()
-            if source_media_md is not None:
-                self.rotation = source_media_md.get_required_rotation()
+            if 'rotation' in self.source_media.md['metadata']:
+                self.rotation = self.source_media.md['metadata']['rotation']
             else:
                 self.rotation = 0
         return self.rotation
@@ -134,9 +115,6 @@ class ImageOtherSize(ResizedImage):
     def get_size(self):
         if self.size is None:
             orig_size = self.source_media.get_size()
-            if self.source_media.broken:
-                return orig_size
-
             if self.get_rotation() in (90, 270, ):
                 # swap coords
                 orig_size = (orig_size[1], orig_size[0], )
@@ -160,10 +138,6 @@ class ImageOtherSize(ResizedImage):
     }
 
     def resize(self, im):
-        self.source_media.get_size()  # Probe brokenness
-        if self.source_media.broken:
-            raise IOError()
-
         rotation = self.get_rotation()
         self.get_size()
 
@@ -215,31 +189,34 @@ class ImageOtherSize(ResizedImage):
         except Exception as e:
             logging.error(_("Could not copy metadata in reduced picture: %s"), e)
 
-    def save(self, im):
-        super(ImageOtherSize, self).save(im)
-
-        if self.webgal.config.get('webgal', 'publish-metadata'):
-            self.copy_metadata()
+    def do_build(self):
+        try:
+            im = self.resize(self.get_image())
+        except OSError:
+            self.source_media.set_broken()
+            # Make the system believe the file was built a long time ago.
+            self.stamp_build(0)
+            self.clean_output()
+        else:
+            self.save(im)
 
 
-class VideoThumb(ResizedImage):
+class VideoThumb(ResizedMedia):
 
     force_extension = '.jpg'
 
     def get_verb(self): return _('VIDEOTHUMB')
     VERB = property(get_verb)
 
-    def get_image(self):
+    def do_build(self):
         try:
-            thumb = mediautils.VideoThumbnailer(self.source_media.path).get_thumb()
+            mediautils.VideoThumbnailer(self.source_media.path) \
+                .convert(self.path, self.get_size())
         except mediautils.VideoError as e:
             logging.error(_("  creating %s thumbnail failed, skipped"),
                           self.source_media.filename)
             logging.info(str(e))
             self.clean_output()
-            raise IOError()
-        else:
-            return thumb
 
 
 class WebalbumPicture(make.FileMakeObject):
@@ -249,12 +226,12 @@ class WebalbumPicture(make.FileMakeObject):
     def __init__(self, webgal_dir):
         self.path = os.path.join(webgal_dir.path,
                                  webgal_dir.get_webalbumpic_filename())
-        make.FileMakeObject.__init__(self, self.path)
+        super().__init__(self.path)
 
         self.add_dependency(webgal_dir.source_dir)
 
         medias = [m for m in webgal_dir.source_dir.get_all_medias()
-                  if m.type == 'image' and not m.broken]
+                  if m.type == 'image']
 
         # Add video thumbs
         for m in webgal_dir.medias:
@@ -305,7 +282,7 @@ class WebVideo(genfile.WebalbumFile):
         self.filename = self.webgal._add_size_qualifier(self.source_video.filename,
                                                         size_name, '.webm')
         path = os.path.join(self.webgal.path, self.filename)
-        genfile.WebalbumFile.__init__(self, path, webgal)
+        super().__init__(path, webgal)
 
         newsizer = self.webgal.newsizers[size_name]
         if newsizer == 'original':
@@ -320,16 +297,16 @@ class WebVideo(genfile.WebalbumFile):
         logging.info(_("  TRANSCODE %s"), vid_rel_path)
 
         try:
-            transcoder = mediautils.WebMTranscoder(self.source_video.path,
-                                                   self.new_width,
-                                                   self.new_height)
+            transcoder = mediautils.WebMTranscoder(self.source_video.path)
+            if self.new_width is not None and self.new_height is not None:
+                transcoder.scale((self.new_width, self.new_height))
             transcoder.set_progress(self.progress)
             transcoder.convert(self.path)
         except mediautils.VideoError as e:
             logging.error(_("  transcoding %s failed, skipped"),
                           self.source_video.filename)
             logging.info(str(e))
-            self.source_video.broken = True
+            self.source_video.set_broken()
             self.clean_output()
         finally:
             self.progress.set_task_done()
