@@ -38,9 +38,7 @@ class WebalbumPage(genfile.WebalbumFile):
 
         page_filename = self._add_size_qualifier(base_name + '.html',
                                                  self.size_name)
-        genfile.WebalbumFile.__init__(self,
-                                      os.path.join(dir.path, page_filename),
-                                      dir)
+        super().__init__(os.path.join(dir.path, page_filename), dir)
 
         self.page_template = None
 
@@ -91,7 +89,7 @@ class WebalbumBrowsePage(WebalbumPage):
     def __init__(self, dir, size_name, webalbum_media):
         self.webalbum_media = webalbum_media
         self.media = self.webalbum_media.media
-        WebalbumPage.__init__(self, dir, size_name, self.media.name)
+        super().__init__(dir, size_name, self.media.name)
 
         self.add_dependency(self.webalbum_media.resized[size_name])
         if webalbum_media.original:
@@ -162,7 +160,7 @@ class WebalbumIndexPage(WebalbumPage):
 
     def __init__(self, dir, size_name, page_number, subgals, galleries):
         page_paginated_name = self._get_paginated_name(page_number)
-        WebalbumPage.__init__(self, dir, size_name, page_paginated_name)
+        super().__init__(dir, size_name, page_paginated_name)
 
         self.page_number = page_number
         self.subgals = subgals
@@ -174,6 +172,7 @@ class WebalbumIndexPage(WebalbumPage):
                 dir.flattening_dir = self.dir
 
             self.add_dependency(dir.pindex)
+            self.add_dependency(dir.webassets)
             self.add_dependency(dir.sort_task)
 
             if size_name in dir.browse_sizes:
@@ -184,16 +183,11 @@ class WebalbumIndexPage(WebalbumPage):
                         self.add_dependency(media.browse_pages[size_name])
                         # Ensure dir depends on browse page (usefull for cleanup
                         # checks when dir is flattenend).
-                        dir.add_dependency(media.browse_pages[size_name])
+                        if self.dir.should_be_flattened():
+                            dir.add_dependency(media.browse_pages[size_name])
             else:
                 logging.warning(_("  Size '%s' is not available in '%s' due to configuration: medias won't be shown on index."), size_name, dir.path)
 
-            if self.dir.pindex.dirzip():
-                self.add_dependency(self.dir.dirzip)
-
-        for subgal in self.subgals:
-            self.add_dependency(subgal.pindex)
-
         if self.dir.album.theme.kind == 'static':
             self.set_template('dirindex.thtml')
         elif self.dir.album.theme.kind == 'dynamic':
@@ -290,7 +284,7 @@ class WebalbumFeed(make.FileMakeObject):
 
     def __init__(self, album, dir_path, pub_url):
         self.path = os.path.join(dir_path, 'index.xml')
-        super(WebalbumFeed, self).__init__(self.path)
+        super().__init__(self.path)
 
         self.album = album
         self.pub_url = pub_url
@@ -356,7 +350,7 @@ class SharedFileTemplate(make.FileMakeObject):
         else:
             raise ValueError(_('We have a template with an extension that does not start with a t. Aborting.'))
 
-        make.FileMakeObject.__init__(self, self.path)
+        super().__init__(self.path)
         self.add_file_dependency(shared_tpl_name)
 
     def build(self):
