@@ -23,11 +23,12 @@ import logging
 import codecs
 import datetime
 
-from .pygexiv2 import GExiv2
-from PIL import Image as PILImage
+import gi
+gi.require_version('GExiv2', '0.10')
+from gi.repository import GExiv2
 
-from . import py2compat
 from . import make
+from . import mediautils
 
 from fractions import Fraction
 
@@ -87,34 +88,28 @@ def decode_exif_user_comment(raw, imgpath):
         cset = None
         text = raw
 
-    if cset == 'Unicode':
-        encoding = None
-        try:
-            py2compat.u(text, 'utf-8')
-        except UnicodeDecodeError:
-            with open(imgpath, 'rb') as im_fp:
-                im = PILImage.open(im_fp)
-                endianess = im.app['APP1'][6:8]
-            if endianess == 'MM':
-                encoding = 'utf-16be'
-            elif endianess == 'II':
-                encoding = 'utf-16le'
-            else:
-                raise ValueError
-        else:
-            encoding = 'utf-8'
-    elif cset == 'Ascii':
-        encoding = 'ascii'
-    elif cset == 'Jis':
-        encoding = 'shift_jis'
-    else:
-        encoding = FALLBACK_ENCODING
+    return text
 
-    # Return the decoded string according to the found encoding.
-    try:
-        return py2compat.u(text, encoding)
-    except UnicodeDecodeError:
-        return py2compat.u(text, encoding, 'replace')
+
+def parse_date(s):
+    d = None
+    last_e = None
+    for f in ('%Y-%m-%dT%H:%M:%S.%f%z',
+              '%Y-%m-%dT%H:%M:%S%z',
+              '%Y-%m-%dT%H:%M:%S.%f',
+              '%Y-%m-%dT%H:%M:%S',
+             ):
+        try:
+            d = datetime.datetime.strptime(s, f)
+        except ValueError as e:
+            last_e = e # try next format
+        else:
+            break # parsing successful
+
+    if d:
+        return d
+    else:
+        raise last_e
 
 
 class FileMetadata(object):
@@ -142,7 +137,10 @@ class ImageInfoTags(object):
 
     def __init__(self, image_path):
         self.image_path = image_path
-        self._metadata = GExiv2.Metadata(self.image_path)
+        try:
+            self._metadata = GExiv2.Metadata(self.image_path)
+        except Exception as e:
+            raise ValueError('cannot load metadata: %s' % e)
 
     def get_date(self):
         """
@@ -155,7 +153,7 @@ class ImageInfoTags(object):
                    ):
             try:
                 dt_str = self._metadata[tag]
-                dt = py2compat.datetime.strptime(dt_str, GEXIV2_DATE_FORMAT)
+                dt = datetime.datetime.strptime(dt_str, GEXIV2_DATE_FORMAT)
             except (KeyError, ValueError) as StrptimeError:
                 # ValueError: bypass errors such as "time data '0000:00:00
                 # 00:00:00' does not match format '%Y:%m:%d %H:%M:%S'"
@@ -249,7 +247,7 @@ class ImageInfoTags(object):
 
     def _fallback_to_encoding(self, encoded_string, encoding=FALLBACK_ENCODING):
         if encoded_string is None: raise ValueError
-        if py2compat.isunicode(encoded_string): return encoded_string
+        if type(encoded_string) is str: return encoded_string
         try:
             return encoded_string.decode(encoding)
         except UnicodeDecodeError:
@@ -440,6 +438,32 @@ class ImageInfoTags(object):
                  for tag in TAGS_OF_INTEREST if tag in self._metadata }
 
 
+class VideoInfoTags(object):
+
+    def __init__(self, path):
+        videoinfo = mediautils.VideoInfo(path).inspect()
+        self.__parse(videoinfo)
+
+    def __parse(self, videoinfo):
+        # size
+        for s in videoinfo['streams']:
+            if s['codec_type'] == 'video':
+                self.size = (s['width'], s['height'])
+                break
+        if self.size is None: # no video stream
+            self.size = (None, None)
+
+        # date
+        try:
+            raw =  videoinfo['format']['tags']['creation_time']
+            self.creation_time = parse_date(raw)
+        except (KeyError, ValueError):
+            self.creation_time = None
+
+    def get_date(self):
+        return self.creation_time
+
+
 class NoMetadata(Exception):
     """
     Exception indicating that no meta data has been found.
@@ -450,7 +474,7 @@ class NoMetadata(Exception):
 class DirectoryMetadata(make.GroupTask):
 
     def __init__(self, dir_path):
-        super(DirectoryMetadata, self).__init__()
+        super().__init__()
 
         self.dir_path = dir_path
         self.add_file_dependency(self.dir_path)
@@ -573,7 +597,7 @@ class DefaultMetadata(make.FileMakeObject):
         self.source_dir = source_dir
 
         metadata_path = os.path.join(self.source_dir.path, MATEW_METADATA)
-        super(DefaultMetadata, self).__init__(metadata_path)
+        super().__init__(metadata_path)
 
         self.album = album
 
