@@ -24,13 +24,12 @@ import json
 
 from PIL import Image
 
-from lazygal import py2compat
 from . import LazygalTestGen, has_symlinks
 import lazygal.config
 from lazygal.generators import WebalbumDir
 from lazygal.sourcetree import Directory
-from lazygal.metadata import GEXIV2_DATE_FORMAT
-from lazygal.pygexiv2 import GExiv2
+from lazygal.metadata import GEXIV2_DATE_FORMAT, GExiv2
+from lazygal.mediautils import VideoProcessor
 
 
 class TestGenerators(LazygalTestGen):
@@ -84,17 +83,28 @@ class TestGenerators(LazygalTestGen):
                              {'media': 1, 'video': 0, 'image': 1})
             self.assertEqual(pindex['subgals'], ['subgal'])
 
-        # Check JSON sugal index
+        # Check JSON subgal index
         with open(os.path.join(dest_path, 'subgal', 'index.json')) as json_fp:
             pindex = json.load(json_fp)
             self.assertEqual(pindex['medias'], {'subgal_img.jpg': {
-                'comment': '',
+                'comment': None,
                 'date': '2010-02-05T23:56:24',
                 'width': 640,
                 'height': 427,
                 'metadata': {
-                    'Exif.Photo.DateTimeDigitized': '2010:02:05 23:56:24',
-                    'Exif.Photo.DateTimeOriginal': '2010:02:05 23:56:24'
+                    'date'        : '2010-02-05T23:56:24',
+                    'comment'     : None,
+                    'rotation'    : 0,
+                    'camera_name' : 'HTC Dream',
+                    'lens_name'   : '',
+                    'flash'       : '',
+                    'exposure'    : 'None',
+                    'iso'         : '',
+                    'fnumber'     : '',
+                    'focal_length': '',
+                    'authorship'  : '',
+                    'keywords'    : [],
+                    'location'    : None,
                 },
                 'type': 'image',
             }})
@@ -162,8 +172,7 @@ class TestGenerators(LazygalTestGen):
         source_subgal = Directory(os.path.join(self.source_dir, 'subgal'),
                                   [], pics, self.album)
         dest_subgal = WebalbumDir(source_subgal, [], self.album, dest_path)
-        expected = map(lambda fn:
-                       py2compat.u(os.path.join(dest_path, 'subgal', fn)),
+        expected = map(lambda fn: os.path.join(dest_path, 'subgal', fn),
                        ['extra_thumb2.jpg',
                         'img6_thumb.jpg',
                         'img6_small.jpg', 'img6_medium.jpg',
@@ -174,8 +183,7 @@ class TestGenerators(LazygalTestGen):
                          sorted(expected))
         source_gal = Directory(self.source_dir, [source_subgal], [], self.album)
         dest_gal = WebalbumDir(source_gal, [dest_subgal], self.album, dest_path)
-        expected =  map(lambda fn:
-                        py2compat.u(os.path.join(dest_path, fn)),
+        expected =  map(lambda fn: os.path.join(dest_path, fn),
                         ['extra_thumb.jpg', 'extra_dir']
                        )
         self.assertEqual(sorted(dest_gal.list_foreign_files()),
@@ -408,6 +416,12 @@ class TestGenerators(LazygalTestGen):
         def long(): return dest_image['Exif.GPSInfo.GPSLatitude']
         self.assertRaises(KeyError, long)
 
+        # Check that metadata is not in the JSON index
+        with open(os.path.join(dest_dir, 'index.json')) as json_fp:
+            pindex = json.load(json_fp)
+            self.assertEqual(pindex['medias']['md_filled.jpg']['metadata']['location'],
+                             None)
+
     def test_metadata_osize_nopublish(self):
         config = lazygal.config.LazygalConfig()
         config.set('webgal', 'publish-metadata', 'No')
@@ -432,6 +446,11 @@ class TestGenerators(LazygalTestGen):
         def com(): return dest_image['Exif.Photo.UserComment']
         self.assertRaises(KeyError, com)
 
+        # Check that metadata is not in the JSON index
+        with open(os.path.join(dest_dir, 'index.json')) as json_fp:
+            pindex = json.load(json_fp)
+            self.assertFalse('metadata' in pindex['medias']['md_filled.jpg'])
+
     def test_resize_rotate_size(self):
         config = lazygal.config.LazygalConfig()
         config.set('webgal', 'image-size', 'std=800x600')
@@ -494,7 +513,7 @@ class TestGenerators(LazygalTestGen):
         tagnotfound_path        = self.add_img(self.source_dir, 'tagnotfound.jpg')
         untagged_path           = self.add_img(self.source_dir, 'untagged.jpg')
         sdir_tagfound           = self.setup_subgal('sdir_tagfound', ['sdir_tagfound.jpg', 'sdir_tagnotfound.jpg'])
-        sdir_tagnotfound        = self.setup_subgal('sdir_tagnotfound', ['sdir_tagfound.jpg', 'sdir_tagnotfound.jpg'])
+        sdir_tagnotfound        = self.setup_subgal('sdir_tagnotfound', ['sdir_tagnotfound.jpg'])
         sdir_untagged           = self.setup_subgal('sdir_untagged', ['untagged.jpg'])
         tagfound_subdir_path    = os.path.join(self.source_dir, sdir_tagfound.name, 'sdir_tagfound.jpg')
         tagnotfound_subdir_path = os.path.join(self.source_dir, sdir_tagnotfound.name, 'sdir_tagnotfound.jpg')
@@ -575,16 +594,23 @@ class TestGenerators(LazygalTestGen):
             raise
 
     def test_withvideo(self):
-        source_subgal = self.setup_subgal('subgal', [], ['vid.mov'])
+        source_subgal = self.setup_subgal('subgal', [], ['vid.mov',
+                                                         'vid-silent.mov'])
+
+        # silence a video to make sure it does not crash
+        silencer = VideoProcessor(os.path.join(source_subgal.path, 'vid.mov'))
+        silencer.cmd.extend(['-c', 'copy', '-an'])
+        # overwrite the existing file
+        silencer.convert(os.path.join(source_subgal.path, 'vid-silent.mov'))
 
         # create empty video file to ensure nothing crashes
-        self.create_file(os.path.join(source_subgal.path, 'vid_broken.mov'))
+        self.create_file(os.path.join(source_subgal.path, 'vid-broken.mov'))
 
         dest_path = self.get_working_path()
 
         self.album.generate(dest_path)
 
-        error = '%s has not been generate though it should have'
+        error = '%s has not been generated though it should have'
 
         # Check root dir contents
         self.assertTrue(os.path.isdir(dest_path))
@@ -597,7 +623,9 @@ class TestGenerators(LazygalTestGen):
         self.assertTrue(os.path.isdir(dest_subgal_path))
         for fn in ('index.html', 'index_medium.html',
                    'vid.html', 'vid_medium.html', 'vid_thumb.jpg',
-                   'vid_video.webm'):
+                   'vid_video.webm',
+                   'vid-silent.html', 'vid-silent_medium.html', 'vid-silent_thumb.jpg',
+                   'vid-silent_video.webm'):
             self.assertTrue(os.path.isfile(os.path.join(dest_subgal_path, fn)),
                             error % fn)
 
@@ -605,7 +633,7 @@ class TestGenerators(LazygalTestGen):
 class TestSpecialGens(LazygalTestGen):
 
     def setUp(self):
-        super(TestSpecialGens, self).setUp(False)
+        super().setUp(False)
         self.dest_path = os.path.join(self.tmpdir, 'dst')
 
     def test_paginate(self):
@@ -701,7 +729,7 @@ class TestSpecialGens(LazygalTestGen):
 class TestSorting(LazygalTestGen):
 
     def setUp(self):
-        super(TestSorting, self).setUp(False)
+        super().setUp(False)
         self.dest_path = os.path.join(self.tmpdir, 'dst')
 
     def __setup_pics(self, subgal_name=None):
