@@ -27,17 +27,15 @@ import codecs
 
 from . import LazygalTest
 from lazygal import metadata
-from lazygal import py2compat
 metadata.FILE_METADATA_ENCODING = 'utf-8'  # force for these tests
 from lazygal.generators import Album
 from lazygal.sourcetree import Directory
-from lazygal.pygexiv2 import GExiv2
 
 
 class TestFileMetadata(LazygalTest):
 
     def setUp(self):
-        super(TestFileMetadata, self).setUp()
+        super().setUp()
 
         self.source_dir = self.get_working_path()
         album = Album(self.source_dir)
@@ -63,7 +61,7 @@ class TestFileMetadata(LazygalTest):
         img_path = self.add_img(self.source_dir, 'captioned_pic.jpg')
 
         # Set dumy comment which should be ignored.
-        im = GExiv2.Metadata(img_path)
+        im = metadata.GExiv2.Metadata(img_path)
         im['Exif.Photo.UserComment'] = 'comment not to show'
         im.save_file()
 
@@ -224,10 +222,6 @@ Album image identifier "first\xe3.jpg"
         im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
         self.assertEqual(im_md.get_focal_length(), '18 mm (35 mm equivalent: 27 mm)')
 
-    @unittest.skipIf(py2compat.PY3RUNNING
-                     and (GExiv2.MAJOR_VERSION, GExiv2.MINOR_VERSION,
-                          GExiv2.MICRO_VERSION) < (0, 10, 3),
-                     'not supported by GExiv2<0.10.3 in python3')
     def test_authorship(self):
         sample = 'sample-author-badencoding.jpg'
         im_md = metadata.ImageInfoTags(self.get_sample_path(sample))
@@ -261,6 +255,13 @@ Album image identifier "first\xe3.jpg"
             'altitude': 1527
         })
 
+    def test_video(self):
+        sample = 'vid.mov'
+        vid_md = metadata.VideoInfoTags(self.get_sample_path(sample))
+        self.assertEqual(vid_md.get_date(),
+                         datetime.datetime(2007, 2, 10, 17, 51, 8,
+                                           tzinfo=datetime.timezone.utc))
+
 
 if __name__ == '__main__':
     unittest.main()
